/* -------------------------------------------------------------------------- */
/* Copyright 2002-2010, OpenNebula Project Leads (OpenNebula.org)             */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

#include "EHDriver.h"
#include "Nebula.h"
#include <sstream>
#include <fstream>
#include <math.h>

int EHDriver::deployment_description(
    const VirtualMachine *  vm,
    const string&           file_name) const
{
    ofstream                    file;

    int                         num;
    vector<const Attribute *>   attrs;
    
    const VectorAttribute * eh;

    string  name         = "";
    string  cpu          = "";
    string  mem          = "";
    string  drive        = "";
    string  boot         = "";
    string  nicmodel     = "";
    string  nicdhcp      = "";
    string  vncip        = "";
    string  vncpassword  = "";

    // ------------------------------------------------------------------------

    file.open(file_name.c_str(), ios::out);

    if (file.fail() == true)
    {
        goto error_file;
    }

    // ------------------------------------------------------------------------
    //  EH parameters
    // ------------------------------------------------------------------------

    num = vm->get_template_attribute("EH",attrs);

    if ( num > 0 )
    {
        eh = dynamic_cast<const VectorAttribute *>(attrs[0]);

        if ( eh != 0 )
        {
            name         = eh->vector_value("NAME");
            cpu          = eh->vector_value("CPUMHZ");            
            mem          = eh->vector_value("MEMORY");            
            drive        = eh->vector_value("DRIVE");
            boot         = eh->vector_value("BOOT");
            nicmodel     = eh->vector_value("NICMODEL");
            nicdhcp      = eh->vector_value("NICDHCP");
            vncip        = eh->vector_value("VNCIP");
            vncpassword  = eh->vector_value("VNCPASSWORD");
        }
        else
        {
            goto error_eh_parameters;
        }
    }
    else
    {
        goto error_eh_parameters;
    }
    
    if ( !name.empty() ) //VM name
    {
        file << "name " << name << endl;
    }
    
    if ( !cpu.empty() ) //VM cpu
    {
        file << "cpu " << cpu << endl;
    }
    
    if ( !mem.empty() ) //VM memory
    {
        file << "mem " << mem << endl;
    }
    
    if ( !drive.empty() ) //VM drive
    {
        file << drive << endl;
    }
    
    if ( !boot.empty() ) //VM boot
    {
        file << "boot " << boot << endl;
    }
    
    if ( !nicmodel.empty() ) //VM nicmodel
    {
        file << nicmodel << endl;
    }
    
    if ( !nicdhcp.empty() ) //VM nicdhcp
    {
        file << nicdhcp << endl;
    }
    
    if ( !vncip.empty() ) //VM vncip
    {
        file << vncip << endl;
    }
    
    if ( !vncpassword.empty() ) //VM vncpassword
    {
        file << vncpassword << endl;
    }

    file.close();

    return 0;

error_file:
    vm->log("VMM", Log::ERROR, "Could not open EH deployment file.");
    return -1;

error_eh_parameters:
    vm->log("VMM", Log::ERROR, "No EH parameters provided.");
    file.close();
    return -1;
}
